# empix

[![Test library](https://github.com/mrfitzpa/empix/actions/workflows/test_library.yml/badge.svg)](https://github.com/mrfitzpa/empix/actions/workflows/test_library.yml)
[![Code Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/mrfitzpa/b7ef7892a2b5cf21ba4b6163c324afbe/raw/empix_coverage_badge.json)](https://github.com/mrfitzpa/empix/actions/workflows/measure_code_coverage.yml)
[![Documentation](https://img.shields.io/badge/docs-read-brightgreen)](https://mrfitzpa.github.io/empix)
[![PyPi Version](https://img.shields.io/pypi/v/empix.svg)](https://pypi.org/project/empix)
[![Conda-Forge Version](https://img.shields.io/conda/vn/conda-forge/empix.svg)](https://anaconda.org/conda-forge/empix)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

`empix` is a Python library that contains tools for analyzing electron
microscopy data that are not available in
[`hyperspy`](https://hyperspy.org/hyperspy-doc/current/index.html).

Visit the `empix` [website](https://mrfitzpa.github.io/empix) for a web version
of the installation instructions, the reference guide, and the examples archive.

<!--
For those reading raw .rst files, see file `docs/INSTALL.rst` for instructions
on installing the `empix` library.
-->